# pysimular

Python API client for Simular agents. This package provides a simple and intuitive interface to interact with Simular's agents in different platforms.

Currently supports SimularBrowser as backend.

## Installation

```bash
pip install pysimular
```

## Quick Start

```python
from pysimular import SimularBrowser

browser = SimularBrowser("your-simular-browser-app-path")
browser.run("your-message")
```

## License

This project is licensed under the Apache License - see the LICENSE file for details.
